@@ -358,7 +358,8 @@ class Verification(object):
 
     @classmethod
     def verify(cls, deployment, set_name="", regex=None, tests_file=None,
-               tempest_config=None, system_wide_install=None, concur=0):
+               tempest_config=None, expected_failures=None, system_wide=False,
+               concur=0):
         """Start verification.
 
         :param deployment: UUID or name of a deployment
@@ -366,19 +367,23 @@ class Verification(object):
         :param regex: Regular expression of test
         :param tests_file: Path to a file with a list of Tempest tests
         :param tempest_config: User specified Tempest config file location
-        :param system_wide_install: Whether or not to create a virtual env
-                                    when installing Tempest; whether or not to
-                                    use the local env instead of the Tempest
-                                    virtual env when running the tests
+        :param expected_failures: Dictionary with Tempest tests that are
+                                  expected to fail. Keys are test names;
+                                  values are reasons of test failures
+        :param system_wide: Whether or not to create a virtual env when
+                            installing Tempest; whether or not to use
+                            the local env instead of the Tempest virtual
+                            env when running the tests
         :param concur: How many processes to use to run Tempest tests.
                        The default value (0) auto-detects CPU count
         :returns: Verification object
         """
         deployment_uuid = objects.Deployment.get(deployment)["uuid"]
         verification = objects.Verification(deployment_uuid=deployment_uuid)
-        verifier = tempest.Tempest(deployment_uuid, verification=verification,
+        verifier = tempest.Tempest(deployment_uuid,
+                                   verification=verification,
                                    tempest_config=tempest_config,
-                                   system_wide_install=system_wide_install)
+                                   system_wide=system_wide)
 
         if not verifier.is_installed():
             LOG.info(_("Tempest is not installed "
@@ -389,8 +394,8 @@ class Verification(object):
 
         LOG.info("Starting verification of deployment: %s" % deployment_uuid)
         verification.set_running()
-        verifier.verify(set_name=set_name, regex=regex,
-                        tests_file=tests_file, concur=concur)
+        verifier.verify(set_name=set_name, regex=regex, tests_file=tests_file,
+                        expected_failures=expected_failures, concur=concur)
 
         return verification
 
@@ -416,16 +421,16 @@ class Verification(object):
         return deployment, verification
 
     @classmethod
-    def install_tempest(cls, deployment, source=None, no_tempest_venv=False):
+    def install_tempest(cls, deployment, source=None, system_wide=False):
         """Install Tempest.
 
         :param deployment: UUID or name of a deployment
         :param source: Path/URL to repo to clone Tempest from
-        :param no_tempest_venv: Whether or not to create a Tempest virtual env
+        :param system_wide: Whether or not to create a Tempest virtual env
         """
         deployment_uuid = objects.Deployment.get(deployment)["uuid"]
         verifier = tempest.Tempest(deployment_uuid, source=source,
-                                   system_wide_install=no_tempest_venv)
+                                   system_wide=system_wide)
         verifier.install()
 
     @classmethod
@@ -440,13 +445,13 @@ class Verification(object):
 
     @classmethod
     def reinstall_tempest(cls, deployment, tempest_config=None,
-                          source=None, no_tempest_venv=False):
+                          source=None, system_wide=False):
         """Uninstall Tempest and install again.
 
         :param deployment: UUID or name of a deployment
         :param tempest_config: User specified Tempest config file location
         :param source: Path/URL to repo to clone Tempest from
-        :param no_tempest_venv: Whether or not to create a Tempest virtual env
+        :param system_wide: Whether or not to create a Tempest virtual env
         """
         deployment_uuid = objects.Deployment.get(deployment)["uuid"]
         verifier = tempest.Tempest(deployment_uuid)
@@ -460,7 +465,7 @@ class Verification(object):
         verifier.uninstall()
         verifier = tempest.Tempest(deployment_uuid, source=source,
                                    tempest_config=tempest_config,
-                                   system_wide_install=no_tempest_venv)
+                                   system_wide=system_wide)
         verifier.install()
         if not tempest_config:
             shutil.move(tmp_conf_path, verifier.config_file)
