@@ -20,6 +20,7 @@ import json
 import os
 
 import six
+import yaml
 
 from rally import api
 from rally.cli import cliutils
@@ -43,34 +44,44 @@ class VerifyCommands(object):
     """
 
     @cliutils.args("--deployment", dest="deployment", type=str,
-                   required=False, help="UUID or name of a deployment")
-    @cliutils.args("--set", dest="set_name", type=str, required=False,
+                   metavar="<uuid>", required=False,
+                   help="UUID or name of a deployment.")
+    @cliutils.args("--set", metavar="<set_name>", dest="set_name", type=str,
+                   required=False,
                    help="Name of a Tempest test set. "
                         "Available sets are %s" % ", ".join(AVAILABLE_SETS))
     @cliutils.args("--regex", dest="regex", type=str, required=False,
-                   help="Regular expression of test")
-    @cliutils.args("--tests-file", dest="tests_file", type=str,
-                   help="Path to a file with a list of Tempest tests",
-                   required=False)
+                   help="Test name regular expression")
+    @cliutils.args("--tests-file", metavar="<path>", dest="tests_file",
+                   type=str, required=False,
+                   help="Path to a file with a list of Tempest tests")
     @cliutils.args("--tempest-config", dest="tempest_config", type=str,
-                   required=False,
-                   help="User specified Tempest config file location")
+                   required=False, metavar="<path>",
+                   help="User-specified Tempest config file location")
+    @cliutils.args("--xfails-file", dest="xfails_file", type=str,
+                   required=False, metavar="<path>",
+                   help="Path to a YAML file with a list of Tempest "
+                        "tests that are expected to fail")
     @cliutils.args("--no-use", action="store_false", dest="do_use",
-                   help="Don't set new task as default for future operations")
-    @cliutils.args("--system-wide-install", dest="system_wide_install",
+                   help="Don't set the task as default for future operations")
+    @cliutils.args("--system-wide", dest="system_wide",
                    help="Don't create a virtual env when installing Tempest; "
                         "use the local env instead of the Tempest virtual env "
-                        "when running the tests. Take notice that all Tempest "
+                        "when running the tests. Note that all Tempest "
                         "requirements have to be already installed in "
                         "the local env!",
                    required=False, action="store_true")
-    @cliutils.args("--concurrency", dest="concur", type=int, required=False,
+    @cliutils.deprecated_args("--system-wide-install", dest="system_wide",
+                              required=False, action="store_true",
+                              release="0.1.2", alternative="--system-wide")
+    @cliutils.args("--concurrency", metavar="N", dest="concur", type=int,
+                   required=False,
                    help="How many processes to use to run Tempest tests. "
                         "The default value (0) auto-detects your CPU count")
     @envutils.with_default_deployment(cli_arg_name="deployment")
     def start(self, deployment=None, set_name="", regex=None,
-              tests_file=None, tempest_config=None, do_use=True,
-              system_wide_install=False, concur=0):
+              tests_file=None, tempest_config=None, xfails_file=None,
+              do_use=True, system_wide=False, concur=0):
         """Start verification (run Tempest tests).
 
         :param deployment: UUID or name of a deployment
@@ -78,11 +89,13 @@ class VerifyCommands(object):
         :param regex: Regular expression of test
         :param tests_file: Path to a file with a list of Tempest tests
         :param tempest_config: User specified Tempest config file location
+        :param xfails_file: Path to a file in YAML format with a list of
+                            Tempest tests that are expected to fail
         :param do_use: Use new task as default for future operations
-        :param system_wide_install: Whether or not to create a virtual env
-                                    when installing Tempest; whether or not to
-                                    use the local env instead of the Tempest
-                                    virtual env when running the tests
+        :param system_wide: Whether or not to create a virtual env when
+                            installing Tempest; whether or not to use
+                            the local env instead of the Tempest virtual
+                            env when running the tests
         :param concur: How many processes to use to run Tempest tests.
                        The default value (0) auto-detects CPU count
         """
@@ -111,20 +124,31 @@ class VerifyCommands(object):
             print(_("File '%s' not found.") % tests_file)
             return 1
 
+        expected_failures = None
+        if xfails_file:
+            if os.path.exists(xfails_file):
+                with open(os.path.abspath(xfails_file), "rb") as f:
+                    expected_failures = yaml.load(f)
+            else:
+                print(_("File '%s' not found.") % xfails_file)
+                return 1
+
         verification = api.Verification.verify(
-            deployment, set_name=set_name, regex=regex,
-            tests_file=tests_file, tempest_config=tempest_config,
-            system_wide_install=system_wide_install, concur=concur)
+            deployment, set_name=set_name, regex=regex, tests_file=tests_file,
+            tempest_config=tempest_config, expected_failures=expected_failures,
+            system_wide=system_wide, concur=concur)
         if do_use:
             self.use(verification["uuid"])
 
     @cliutils.args("--deployment", dest="deployment", type=str,
-                   required=False, help="UUID or name of a deployment")
-    @cliutils.args("--set", dest="set_name", type=str, required=False,
+                   metavar="<uuid>", required=False,
+                   help="UUID or name of a deployment.")
+    @cliutils.args("--set", metavar="<set_name>", dest="set_name", type=str,
+                   required=False,
                    help="Name of a Tempest test set. "
                         "Available sets are %s" % ", ".join(AVAILABLE_SETS))
     @cliutils.args("--file", dest="log_file", type=str,
-                   required=True,
+                   required=True, metavar="<path>",
                    help="User specified Tempest log file location. "
                         "Note, Tempest log file needs to be in subunit format")
     @cliutils.args("--no-use", action="store_false", dest="do_use",
@@ -148,7 +172,7 @@ class VerifyCommands(object):
             self.use(verification["uuid"])
 
     def list(self):
-        """Display verifications table."""
+        """List verification runs."""
 
         fields = ["UUID", "Deployment UUID", "Set name", "Tests", "Failures",
                   "Created at", "Duration", "Status"]
@@ -164,28 +188,28 @@ class VerifyCommands(object):
             print(_("No verification was started yet. "
                     "To start verification use:\nrally verify start"))
 
-    @cliutils.args("--uuid", type=str, dest="verification_uuid",
-                   help="UUID of a verification")
+    @cliutils.args("--uuid", type=str, dest="verification",
+                   help="UUID of a verification.")
     @cliutils.args("--html", action="store_true", dest="output_html",
-                   help="Display results in HTML format")
+                   help="Display results in HTML format.")
     @cliutils.args("--json", action="store_true", dest="output_json",
-                   help="Display results in JSON format")
+                   help="Display results in JSON format.")
     @cliutils.args("--output-file", type=str, required=False,
-                   dest="output_file",
-                   help="Path to a file to save results")
+                   dest="output_file", metavar="<path>",
+                   help="Path to a file to save results to.")
     @envutils.with_default_verification_id
     @cliutils.suppress_warnings
-    def results(self, verification_uuid=None, output_file=None,
+    def results(self, verification=None, output_file=None,
                 output_html=None, output_json=None):
         """Display results of a verification.
 
-        :param verification_uuid: UUID of a verification
+        :param verification: UUID of a verification
         :param output_file: Path to a file to save results
         :param output_html: Display results in HTML format
         :param output_json: Display results in JSON format (Default)
         """
         try:
-            results = api.Verification.get(verification_uuid).get_results()
+            results = api.Verification.get(verification).get_results()
         except exceptions.NotFoundException as e:
             print(six.text_type(e))
             return 1
@@ -206,30 +230,25 @@ class VerifyCommands(object):
         else:
             print(result)
 
-    @cliutils.args("--uuid", dest="verification_uuid", type=str,
+    @cliutils.args("--uuid", dest="verification", type=str,
                    required=False,
                    help="UUID of a verification")
-    @cliutils.args("--sort-by", dest="sort_by", type=str, required=False,
+    @cliutils.args("--sort-by", metavar="<query>", dest="sort_by", type=str,
+                   required=False, choices=("name", "duration"),
                    help="Sort results by 'name' or 'duration'")
     @cliutils.args("--detailed", dest="detailed", action="store_true",
                    required=False,
                    help="Display detailed errors of failed tests")
     @envutils.with_default_verification_id
-    def show(self, verification_uuid=None, sort_by="name", detailed=False):
+    def show(self, verification=None, sort_by="name", detailed=False):
         """Display results table of a verification.
 
-        :param verification_uuid: UUID of a verification
+        :param verification: UUID of a verification
         :param sort_by: Sort results by 'name' or 'duration'
         :param detailed: Display detailed errors of failed tests
         """
         try:
-            sortby_index = ("name", "duration").index(sort_by)
-        except ValueError:
-            print(_("Verification results can't be sorted by '%s'.") % sort_by)
-            return 1
-
-        try:
-            verification = api.Verification.get(verification_uuid)
+            verification = api.Verification.get(verification)
             tests = verification.get_results()
         except exceptions.NotFoundException as e:
             print(six.text_type(e))
@@ -245,6 +264,7 @@ class VerifyCommands(object):
 
         results = tests["test_cases"]
         values = [utils.Struct(**results[test_name]) for test_name in results]
+        sortby_index = ("name", "duration").index(sort_by)
         cliutils.print_list(values, fields, sortby_index=sortby_index)
 
         if detailed:
@@ -259,22 +279,22 @@ class VerifyCommands(object):
                         "log": test["traceback"]}
                     print(formatted_test)
 
-    @cliutils.args("--uuid", dest="verification_uuid", type=str,
-                   required=False, help="UUID of a verification")
-    @cliutils.args("--sort-by", dest="sort_by", type=str, required=False,
-                   help="Sort results by 'name' or 'duration'")
+    @cliutils.args("--uuid", dest="verification", type=str,
+                   required=False, help="UUID of a verification.")
+    @cliutils.args("--sort-by", dest="sort_by", choices=("name", "duration"),
+                   required=False, help="Sort results by 'name' or 'duration'")
     @envutils.with_default_verification_id
-    def detailed(self, verification_uuid=None, sort_by="name"):
+    def detailed(self, verification=None, sort_by="name"):
         """Display results table of a verification with detailed errors.
 
-        :param verification_uuid: UUID of a verification
+        :param verification: UUID of a verification
         :param sort_by: Sort results by 'name' or 'duration'
         """
-        self.show(verification_uuid, sort_by, True)
+        self.show(verification, sort_by, True)
 
-    @cliutils.args("--uuid-1", type=str, required=True, dest="uuid1",
+    @cliutils.args("--uuid-1", type=str, required=True, dest="verification1",
                    help="UUID of the first verification")
-    @cliutils.args("--uuid-2", type=str, required=True, dest="uuid2",
+    @cliutils.args("--uuid-2", type=str, required=True, dest="verification2",
                    help="UUID of the second verification")
     @cliutils.args("--csv", action="store_true", dest="output_csv",
                    help="Display results in CSV format")
@@ -288,13 +308,13 @@ class VerifyCommands(object):
                    dest="threshold", default=0,
                    help="If specified, timing differences must exceed this "
                    "percentage threshold to be included in output")
-    def compare(self, uuid1=None, uuid2=None,
+    def compare(self, verification1=None, verification2=None,
                 output_file=None, output_csv=None, output_html=None,
                 output_json=None, threshold=0):
         """Compare two verification results.
 
-        :param uuid1: UUID of the first verification
-        :param uuid2: UUID of the second verification
+        :param verification1: UUID of the first verification
+        :param verification2: UUID of the second verification
         :param output_file: Path to a file to save results
         :param output_csv: Display results in CSV format
         :param output_html: Display results in HTML format
@@ -302,8 +322,10 @@ class VerifyCommands(object):
         :param threshold: Timing difference threshold percentage
         """
         try:
-            res_1 = api.Verification.get(uuid1).get_results()["test_cases"]
-            res_2 = api.Verification.get(uuid2).get_results()["test_cases"]
+            res_1 = api.Verification.get(
+                verification1).get_results()["test_cases"]
+            res_2 = api.Verification.get(
+                verification2).get_results()["test_cases"]
             _diff = diff.Diff(res_1, res_2, threshold)
         except exceptions.NotFoundException as e:
             print(six.text_type(e))
@@ -331,8 +353,12 @@ class VerifyCommands(object):
         else:
             print(result)
 
-    @cliutils.args("--verification", type=str, dest="verification",
+    @cliutils.args("--uuid", type=str, dest="verification",
                    required=False, help="UUID of a verification")
+    @cliutils.deprecated_args("--verification", dest="verification",
+                              required=False, type=str,
+                              release="0.2.0",
+                              alternative="--uuid")
     def use(self, verification):
         """Set active verification.
 
@@ -343,81 +369,92 @@ class VerifyCommands(object):
         fileutils.update_globals_file("RALLY_VERIFICATION", verification)
 
     @cliutils.args("--deployment", dest="deployment", type=str,
-                   required=False, help="UUID or name of a deployment")
+                   metavar="<uuid>", required=False,
+                   help="UUID or name of a deployment.")
     @cliutils.args("--tempest-config", dest="tempest_config", type=str,
-                   required=False,
-                   help="User specified Tempest config file location")
+                   required=False, metavar="<path>",
+                   help="User-specified Tempest config file location")
     @cliutils.args("--override", dest="override",
                    help="Override existing Tempest config file",
                    required=False, action="store_true")
     @envutils.with_default_deployment(cli_arg_name="deployment")
     def genconfig(self, deployment=None, tempest_config=None, override=False):
-        """Generate configuration file of Tempest.
+        """Generate Tempest configuration file.
 
         :param deployment: UUID or name of a deployment
-        :param tempest_config: User specified Tempest config file location
+        :param tempest_config: User-specified Tempest config file location
         :param override: Whether or not to override existing Tempest
                          config file
         """
         api.Verification.configure_tempest(deployment, tempest_config,
                                            override)
 
-    @cliutils.args("--deployment", type=str, dest="deployment",
-                   required=False, help="UUID or name of a deployment")
+    @cliutils.args("--deployment", dest="deployment", type=str,
+                   metavar="<uuid>", required=False,
+                   help="UUID or name of a deployment.")
     @cliutils.args("--source", type=str, dest="source", required=False,
                    help="Path/URL to repo to clone Tempest from")
-    @cliutils.args("--no-tempest-venv", dest="no_tempest_venv",
-                   help="Don't create a virtual env for Tempest. Take notice "
+    @cliutils.args("--system-wide", dest="system_wide",
+                   help="Don't create a virtual env for Tempest. Note "
                         "that all Tempest requirements have to be already "
                         "installed in the local env!",
                    required=False, action="store_true")
+    @cliutils.deprecated_args("--no-tempest-venv", dest="system_wide",
+                              required=False, action="store_true",
+                              release="0.2.0", alternative="--system-wide")
     @envutils.with_default_deployment(cli_arg_name="deployment")
-    def install(self, deployment=None, source=None, no_tempest_venv=False):
+    def install(self, deployment=None, source=None, system_wide=False):
         """Install Tempest.
 
         :param deployment: UUID or name of a deployment
         :param source: Path/URL to repo to clone Tempest from
-        :param no_tempest_venv: Whether or not to create a Tempest virtual env
+        :param system_wide: Whether or not to create a Tempest virtual env
         """
-        api.Verification.install_tempest(deployment, source, no_tempest_venv)
+        api.Verification.install_tempest(deployment, source, system_wide)
 
-    @cliutils.args("--deployment", type=str, dest="deployment",
-                   required=False, help="UUID or name of a deployment")
+    @cliutils.args("--deployment", dest="deployment", type=str,
+                   metavar="<uuid>", required=False,
+                   help="UUID or name of a deployment.")
     @envutils.with_default_deployment(cli_arg_name="deployment")
     def uninstall(self, deployment=None):
-        """Remove deployment's local Tempest installation.
+        """Remove the deployment's local Tempest installation.
 
         :param deployment: UUID or name of a deployment
         """
         api.Verification.uninstall_tempest(deployment)
 
-    @cliutils.args("--deployment", type=str, dest="deployment",
-                   required=False, help="UUID or name of a deployment")
+    @cliutils.args("--deployment", dest="deployment", type=str,
+                   metavar="<uuid>", required=False,
+                   help="UUID or name of a deployment.")
     @cliutils.args("--tempest-config", dest="tempest_config", type=str,
-                   required=False,
+                   required=False, metavar="<path>",
                    help="User specified Tempest config file location")
     @cliutils.args("--source", type=str, dest="source", required=False,
                    help="Path/URL to repo to clone Tempest from")
-    @cliutils.args("--no-tempest-venv", dest="no_tempest_venv",
-                   help="Don't create a virtual env for Tempest. Take notice "
+    @cliutils.args("--system-wide", dest="system_wide",
+                   help="Don't create a virtual env for Tempest. Note "
                         "that all Tempest requirements have to be already "
                         "installed in the local env!",
                    required=False, action="store_true")
+    @cliutils.deprecated_args("--no-tempest-venv", dest="system_wide",
+                              required=False, action="store_true",
+                              release="0.2.0", alternative="--system-wide")
     @envutils.with_default_deployment(cli_arg_name="deployment")
     def reinstall(self, deployment=None,
-                  tempest_config=None, source=None, no_tempest_venv=False):
+                  tempest_config=None, source=None, system_wide=False):
         """Uninstall Tempest and install again.
 
         :param deployment: UUID or name of a deployment
         :param tempest_config: User specified Tempest config file location
         :param source: Path/URL to repo to clone Tempest from
-        :param no_tempest_venv: Whether or not to create a Tempest virtual env
+        :param system_wide: Whether or not to create a Tempest virtual env
         """
         api.Verification.reinstall_tempest(deployment, tempest_config,
-                                           source, no_tempest_venv)
+                                           source, system_wide)
 
-    @cliutils.args("--deployment", type=str, dest="deployment",
-                   required=False, help="UUID or name of a deployment")
+    @cliutils.args("--deployment", dest="deployment", type=str,
+                   metavar="<uuid>", required=False,
+                   help="UUID or name of a deployment.")
     @envutils.with_default_deployment(cli_arg_name="deployment")
     def showconfig(self, deployment=None):
         """Show configuration file of Tempest.
