@@ -165,8 +165,8 @@ def first_index(lst, predicate):
     :returns: the index of the first matching element or None if no element
               matches the predicate.
     """
-    for i in range(len(lst)):
-        if predicate(lst[i]):
+    for i, e in enumerate(lst):
+        if predicate(e):
             return i
     return None
 
@@ -233,9 +233,10 @@ class RandomNameGeneratorMixin(object):
 
     This mixin provides one method,
     ``generate_random_name()``. Classes that include it must provide a
-    ``self.task`` attribute that references a task dict. Classes that
-    use this mixin may set two class variables to alter the behavior
-    of ``generate_random_name()``:
+    ``self.task`` attribute that references a task dict or a
+    ``self.verification`` attribute that references a verification dict.
+    Classes that use this mixin may set two class variables to alter the
+    behavior of ``generate_random_name()``:
 
     * ``RESOURCE_NAME_FORMAT``: A mktemp(1)-like format string that
       will be used to pattern the generated random string. It must
@@ -275,7 +276,10 @@ class RandomNameGeneratorMixin(object):
 
         :returns: str, pseudo-random name
         """
-        task_id = self.task["uuid"]
+        if hasattr(self, "task"):
+            task_id = self.task["uuid"]
+        elif hasattr(self, "verification"):
+            task_id = self.verification["uuid"]
 
         match = _resource_name_placeholder_re.match(self.RESOURCE_NAME_FORMAT)
         if match is None:
@@ -464,7 +468,7 @@ def interruptable_sleep(sleep_time, atomic_delay=0.1):
     This should give a chance to interrupt current thread.
 
     :param sleep_time: idle time of method (in seconds).
-    :param atomic_delay: parameter with wich  time.sleep would be called
+    :param atomic_delay: parameter with which  time.sleep would be called
                          int(sleep_time / atomic_delay) times.
     """
     if atomic_delay <= 0:
@@ -514,7 +518,7 @@ def timeout_thread(queue):
 
     all_threads = collections.deque()
     while True:
-        if len(all_threads) == 0:
+        if not all_threads:
             timeout = None
         else:
             thread_ident, deadline = all_threads[0]
