@@ -17,10 +17,10 @@ from keystoneclient import exceptions as keystone_exc
 import mock
 from oslo_config import cfg
 from six import moves
+import sqlalchemy.exc
 
 from rally.cli import cliutils
 from rally.cli.commands import deployment
-from rally.cli.commands import info
 from rally.cli.commands import show
 from rally.cli.commands import task
 from rally.cli.commands import verify
@@ -38,7 +38,6 @@ class CliUtilsTestCase(test.TestCase):
         super(CliUtilsTestCase, self).setUp()
         self.categories = {
             "deployment": deployment.DeploymentCommands,
-            "info": info.InfoCommands,
             "show": show.ShowCommands,
             "task": task.TaskCommands,
             "verify": verify.VerifyCommands
@@ -194,11 +193,6 @@ class CliUtilsTestCase(test.TestCase):
         ret = cliutils.run(["rally", "bash-completion"], self.categories)
         self.assertEqual(ret, 0)
 
-    def test_run_bash_completion_with_query_category(self):
-        ret = cliutils.run(["rally", "bash-completion", "info"],
-                           self.categories)
-        self.assertEqual(ret, 0)
-
     def test_run_show(self):
         ret = cliutils.run(["rally", "show", "keypairs"], self.categories)
         self.assertEqual(ret, 1)
@@ -229,6 +223,17 @@ class CliUtilsTestCase(test.TestCase):
                            {"failure": FailuresCommands})
         self.assertEqual(1, ret)
 
+    def test_run_sqlalchmey_operational_failure(self):
+
+        class SQLAlchemyCommands(object):
+
+            def operational_failure(self):
+                raise sqlalchemy.exc.OperationalError("Can't open DB file")
+
+        ret = cliutils.run(["rally", "failure", "operational_failure"],
+                           {"failure": SQLAlchemyCommands})
+        self.assertEqual(1, ret)
+
     def test_print_list(self):
         class TestObj(object):
             x = 1
