@@ -56,7 +56,7 @@ class TaskTestCase(test.TestCase):
                 return_value="some_uuid")
     @mock.patch("rally.common.objects.task.db.task_create")
     def test_init_with_fake_true(self, mock_task_create, mock_uuid4):
-        task = objects.Task(fake=True)
+        task = objects.Task(temporary=True)
         self.assertFalse(mock_task_create.called)
         self.assertTrue(mock_uuid4.called)
         self.assertEqual(task["uuid"], mock_uuid4.return_value)
@@ -175,7 +175,7 @@ class TaskTestCase(test.TestCase):
 
         now = datetime.datetime.now()
         iterations = [
-            {"timestamp": i + 2, "error": [], "duration": i + 5,
+            {"timestamp": i + 2, "duration": i + 5,
              "scenario_output": {"errors": "", "data": {}},
              "error": [], "idle_duration": i,
              "atomic_actions": {
@@ -193,7 +193,7 @@ class TaskTestCase(test.TestCase):
                  "atomic": {"keystone.create_user": {"max_duration": 19,
                                                      "min_duration": 10}},
              "iterations_count": 10, "iterations_failed": 0,
-             "max_duration": 14, "min_duration": 5, "output_names": [],
+             "max_duration": 14, "min_duration": 5,
              "tstamp_start": 2, "full_duration": 40, "load_duration": 32}}]
 
         # serializable is default
